@@ -5,18 +5,19 @@ from .configure import api_key
 
 def main():
     parser = argparse.ArgumentParser(description="Gerador de mensagens de commit com IA")
-    parser.add_argument("-c", action="store_true", help="Commits with the generated message")
-    parser.add_argument("-cp", action="store_true", help="Commits and pushes with the generated message")
-    parser.add_argument("--configure", action="store_true", help="Configures the GEMINI_API_KEY environment variable")
+    parser.add_argument("-c", "--commit", action="store_true", help="Commits with the generated message")
+    parser.add_argument("-cp", "--commitpush",  action="store_true", help="Commits and pushes with the generated message")
+    parser.add_argument("-cf","--configure", action="store_true", help="Configures the GEMINI_API_KEY environment variable")
     args = parser.parse_args()
 
-    mensagem = gerar_mensagem_commit()
+    if not args.cf:
+        mensagem = gerar_mensagem_commit()
 
-    if "No changes detected" in mensagem:
-        print(mensagem)
-        return
+        if "No changes detected" in mensagem:
+            print(mensagem)
+            return
 
-    print("\nGenerated commit message:\n" + mensagem)
+        print("\nGenerated commit message:\n" + mensagem)
 
     if args.c or args.cp:
         print("\nCommitting changes...")
@@ -26,7 +27,7 @@ def main():
         print("\nPushing changes...")
         subprocess.run(["git", "push"])
     
-    if args.configure:
+    if args.cf:
         print("\nPlease input your API KEY\nThis is directly set in the .env file\n")
         key = input()
         api_key(key)
